==> ldap-account-manager_5.2.orig.tar.bz2: ldap-account-manager-5.2/templates/lib/extra/ckeditor/plugins/specialchar/dialogs/lang/sq.js <==
﻿/**
 * @license Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or http://ckeditor.com/license
 */

CKEDITOR.plugins.setLang( 'specialchar', 'sq', {
	euro: 'Shenja e Euros',
	lsquo: 'Thonjëza majtas me një vi',
	rsquo: 'Thonjëza djathtas me një vi',
	ldquo: 'Thonjëza majtas',
	rdquo: 'Thonjëza djathtas',
	ndash: 'En viza lidhëse',
	mdash: 'Em viza lidhëse',
	iexcl: 'Pikëçuditëse e përmbysur',
	cent: 'Shenja e Centit',
	pound: 'Shejna e Funtit',
	curren: 'Shenja e valutës',
	yen: 'Shenja e Jenit',
	brvbar: 'Viza e këputur',
	sect: 'Shenja e pjesës',
	uml: 'Diaeresis',
	copy: 'Shenja e të drejtave të kopjimit',
	ordf: 'Feminine ordinal indicator', // MISSING
	laquo: 'Left-pointing double angle quotation mark', // MISSING
	not: 'Nuk ka shenjë',
	reg: 'Shenja e të regjistruarit',
	macr: 'Macron',
	deg: 'Shenja e shkallës',
	sup2: 'Super-skripta dy',
	sup3: 'Super-skripta tre',
	acute: 'Theks i mprehtë',
	micro: 'Shjenja e Mikros',
	para: 'Pilcrow sign', // MISSING
	middot: 'Pika e Mesme',
	cedil: 'Hark nën shkronja',
	sup1: 'Super-skripta një',
	ordm: 'Masculine ordinal indicator', // MISSING
	raquo: 'Right-pointing double angle quotation mark', // MISSING
	frac14: 'Thyesa një të katrat',
	frac12: 'Thyesa një të dytat',
	frac34: 'Thyesa tre të katrat',
	iquest: 'Pikëpyetje e përmbysur',
	Agrave: 'Shkronja e madhe latine A me theks të rëndë',
	Aacute: 'Shkronja e madhe latine A me theks akute',
	Acirc: 'Shkronja e madhe latine A me theks lakor',
	Atilde: 'Shkronja e madhe latine A me tildë',
	Auml: 'Shkronja e madhe latine A me dy pika',
	Aring: 'Shkronja e madhe latine A me unazë mbi',
	AElig: 'Shkronja e madhe latine Æ',
	Ccedil: 'Shkronja e madhe latine C me hark poshtë',
	Egrave: 'Shkronja e madhe latine E me theks të rëndë',
	Eacute: 'Shkronja e madhe latine E me theks akute',
	Ecirc: 'Shkronja e madhe latine E me theks lakor',
	Euml: 'Shkronja e madhe latine E me dy pika',
	Igrave: 'Shkronja e madhe latine I me theks të rëndë',
	Iacute: 'Shkronja e madhe latine I me theks akute',
	Icirc: 'Shkronja e madhe latine I me theks lakor',
	Iuml: 'Shkronja e madhe latine I me dy pika',
	ETH: 'Shkronja e madhe latine Eth',
	Ntilde: 'Shkronja e madhe latine N me tildë',
	Ograve: 'Shkronja e madhe latine O me theks të rëndë',
	Oacute: 'Shkronja e madhe latine O me theks akute',
	Ocirc: 'Shkronja e madhe latine O me theks lakor',
	Otilde: 'Shkronja e madhe latine O me tildë',
	Ouml: 'Shkronja e madhe latine O me dy pika',
	times: 'Shenja e shumëzimit',
	Oslash: 'Shkronja e madhe latine O me vizë në mes',
	Ugrave: 'Shkronja e madhe latine U me theks të rëndë',
	Uacute: 'Shkronja e madhe latine U me theks akute',
	Ucirc: 'Shkronja e madhe latine U me theks lakor',
	Uuml: 'Shkronja e madhe latine U me dy pika',
	Yacute: 'Shkronja e madhe latine Y me theks akute',
	THORN: 'Shkronja e madhe latine Thorn',
	szlig: 'Shkronja e vogë latine s e mprehtë',
	agrave: 'Shkronja e vogë latine a me theks të rëndë',
	aacute: 'Shkronja e vogë latine a me theks të mprehtë',
	acirc: 'Shkronja e vogël latine a me theks lakor',
	atilde: 'Shkronja e vogël latine a me tildë',
	auml: 'Shkronja e vogël latine a me dy pika',
	aring: 'Shkronja e vogë latine a me unazë mbi',
	aelig: 'Shkronja e vogë latine æ',
	ccedil: 'Shkronja e vogël latine c me hark poshtë',
	egrave: 'Shkronja e vogë latine e me theks të rëndë',
	eacute: 'Shkronja e vogë latine e me theks të mprehtë',
	ecirc: 'Shkronja e vogël latine e me theks lakor',
	euml: 'Shkronja e vogël latine e me dy pika',
	igrave: 'Shkronja e vogë latine i me theks të rëndë',
	iacute: 'Shkronja e vogë latine i me theks të mprehtë',
	icirc: 'Shkronja e vogël latine i me theks lakor',
	iuml: 'Shkronja e vogël latine i me dy pika',
	eth: 'Shkronja e vogë latine eth',
	ntilde: 'Shkronja e vogël latine n me tildë',
	ograve: 'Shkronja e vogë latine o me theks të rëndë',
	oacute: 'Shkronja e vogë latine o me theks të mprehtë',
	ocirc: 'Shkronja e vogël latine o me theks lakor',
	otilde: 'Shkronja e vogël latine o me tildë',
	ouml: 'Shkronja e vogël latine o me dy pika',
	divide: 'Shenja ndarëse',
	oslash: 'Shkronja e vogël latine o me vizë në mes',
	ugrave: 'Shkronja e vogë latine u me theks të rëndë',
	uacute: 'Shkronja e vogë latine u me theks të mprehtë',
	ucirc: 'Shkronja e vogël latine u me theks lakor',
	uuml: 'Shkronja e vogël latine u me dy pika',
	yacute: 'Shkronja e vogë latine y me theks të mprehtë',
	thorn: 'Shkronja e vogël latine thorn',
	yuml: 'Shkronja e vogël latine y me dy pika',
	OElig: 'Shkronja e madhe e bashkuar latine OE',
	oelig: 'Shkronja e vogël e bashkuar latine oe',
	'372': 'Shkronja e madhe latine W me theks lakor',
	'374': 'Shkronja e madhe latine Y me theks lakor',
	'373': 'Shkronja e vogël latine w me theks lakor',
	'375': 'Shkronja e vogël latine y me theks lakor',
	sbquo: 'Single low-9 quotation mark', // MISSING
	'8219': 'Single high-reversed-9 quotation mark', // MISSING
	bdquo: 'Double low-9 quotation mark', // MISSING
	hellip: 'Horizontal ellipsis', // MISSING
	trade: 'Shenja e Simbolit Tregtarë',
	'9658': 'Black right-pointing pointer', // MISSING
	bull: 'Pulla',
	rarr: 'Shigjeta djathtas',
	rArr: 'Shenja të dyfishta djathtas',
	hArr: 'Shigjeta e dyfishë majtas-djathtas',
	diams: 'Black diamond suit', // MISSING
	asymp: 'Gati e barabar me'
} );

==> ldap-account-manager_6.7.orig.tar.bz2: ldap-account-manager-6.7/templates/lib/extra/ckeditor/plugins/specialchar/dialogs/lang/sq.js <==
﻿/**
 * @license Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */

CKEDITOR.plugins.setLang( 'specialchar', 'sq', {
	euro: 'Shenja e Euros',
	lsquo: 'Thonjëza majtas me një vi',
	rsquo: 'Thonjëza djathtas me një vi',
	ldquo: 'Thonjëza majtas',
	rdquo: 'Thonjëza djathtas',
	ndash: 'En viza lidhëse',
	mdash: 'Em viza lidhëse',
	iexcl: 'Pikëçuditëse e përmbysur',
	cent: 'Shenja e Centit',
	pound: 'Shejna e Funtit',
	curren: 'Shenja e valutës',
	yen: 'Shenja e Jenit',
	brvbar: 'Viza e këputur',
	sect: 'Shenja e pjesës',
	uml: 'Diaeresis',
	copy: 'Shenja e të drejtave të kopjimit',
	ordf: 'Tregues rendor femror',
	laquo: 'Thonjëz me dy kënde e kthyer majtas',
	not: 'Nuk ka shenjë',
	reg: 'Shenja e të regjistruarit',
	macr: 'Macron',
	deg: 'Shenja e shkallës',
	sup2: 'Super-skripta dy',
	sup3: 'Super-skripta tre',
	acute: 'Theks i mprehtë',
	micro: 'Shjenja e Mikros',
	para: 'Shenja Pilkrou',
	middot: 'Pika e Mesme',
	cedil: 'Hark nën shkronja',
	sup1: 'Super-skripta një',
	ordm: 'Tregues rendor mashkullor',
	raquo: 'Thonjëz me dy kënde e kthyer djathtas',
	frac14: 'Thyesa një të katrat',
	frac12: 'Thyesa një të dytat',
	frac34: 'Thyesa tre të katrat',
	iquest: 'Pikëpyetje e përmbysur',
	Agrave: 'Shkronja e madhe latine A me theks të rëndë',
	Aacute: 'Shkronja e madhe latine A me theks akute',
	Acirc: 'Shkronja e madhe latine A me theks lakor',
	Atilde: 'Shkronja e madhe latine A me tildë',
	Auml: 'Shkronja e madhe latine A me dy pika',
	Aring: 'Shkronja e madhe latine A me unazë mbi',
	AElig: 'Shkronja e madhe latine Æ',
	Ccedil: 'Shkronja e madhe latine C me hark poshtë',
	Egrave: 'Shkronja e madhe latine E me theks të rëndë',
	Eacute: 'Shkronja e madhe latine E me theks akute',
	Ecirc: 'Shkronja e madhe latine E me theks lakor',
	Euml: 'Shkronja e madhe latine E me dy pika',
	Igrave: 'Shkronja e madhe latine I me theks të rëndë',
	Iacute: 'Shkronja e madhe latine I me theks akute',
	Icirc: 'Shkronja e madhe latine I me theks lakor',
	Iuml: 'Shkronja e madhe latine I me dy pika',
	ETH: 'Shkronja e madhe latine Eth',
	Ntilde: 'Shkronja e madhe latine N me tildë',
	Ograve: 'Shkronja e madhe latine O me theks të rëndë',
	Oacute: 'Shkronja e madhe latine O me theks akute',
	Ocirc: 'Shkronja e madhe latine O me theks lakor',
	Otilde: 'Shkronja e madhe latine O me tildë',
	Ouml: 'Shkronja e madhe latine O me dy pika',
	times: 'Shenja e shumëzimit',
	Oslash: 'Shkronja e madhe latine O me vizë në mes',
	Ugrave: 'Shkronja e madhe latine U me theks të rëndë',
	Uacute: 'Shkronja e madhe latine U me theks akute',
	Ucirc: 'Shkronja e madhe latine U me theks lakor',
	Uuml: 'Shkronja e madhe latine U me dy pika',
	Yacute: 'Shkronja e madhe latine Y me theks akute',
	THORN: 'Shkronja e madhe latine Thorn',
	szlig: 'Shkronja e vogë latine s e mprehtë',
	agrave: 'Shkronja e vogë latine a me theks të rëndë',
	aacute: 'Shkronja e vogë latine a me theks të mprehtë',
	acirc: 'Shkronja e vogël latine a me theks lakor',
	atilde: 'Shkronja e vogël latine a me tildë',
	auml: 'Shkronja e vogël latine a me dy pika',
	aring: 'Shkronja e vogë latine a me unazë mbi',
	aelig: 'Shkronja e vogë latine æ',
	ccedil: 'Shkronja e vogël latine c me hark poshtë',
	egrave: 'Shkronja e vogë latine e me theks të rëndë',
	eacute: 'Shkronja e vogë latine e me theks të mprehtë',
	ecirc: 'Shkronja e vogël latine e me theks lakor',
	euml: 'Shkronja e vogël latine e me dy pika',
	igrave: 'Shkronja e vogë latine i me theks të rëndë',
	iacute: 'Shkronja e vogë latine i me theks të mprehtë',
	icirc: 'Shkronja e vogël latine i me theks lakor',
	iuml: 'Shkronja e vogël latine i me dy pika',
	eth: 'Shkronja e vogë latine eth',
	ntilde: 'Shkronja e vogël latine n me tildë',
	ograve: 'Shkronja e vogë latine o me theks të rëndë',
	oacute: 'Shkronja e vogë latine o me theks të mprehtë',
	ocirc: 'Shkronja e vogël latine o me theks lakor',
	otilde: 'Shkronja e vogël latine o me tildë',
	ouml: 'Shkronja e vogël latine o me dy pika',
	divide: 'Shenja ndarëse',
	oslash: 'Shkronja e vogël latine o me vizë në mes',
	ugrave: 'Shkronja e vogë latine u me theks të rëndë',
	uacute: 'Shkronja e vogë latine u me theks të mprehtë',
	ucirc: 'Shkronja e vogël latine u me theks lakor',
	uuml: 'Shkronja e vogël latine u me dy pika',
	yacute: 'Shkronja e vogë latine y me theks të mprehtë',
	thorn: 'Shkronja e vogël latine thorn',
	yuml: 'Shkronja e vogël latine y me dy pika',
	OElig: 'Shkronja e madhe e bashkuar latine OE',
	oelig: 'Shkronja e vogël e bashkuar latine oe',
	'372': 'Shkronja e madhe latine W me theks lakor',
	'374': 'Shkronja e madhe latine Y me theks lakor',
	'373': 'Shkronja e vogël latine w me theks lakor',
	'375': 'Shkronja e vogël latine y me theks lakor',
	sbquo: 'Thonjëz-9 e vetme poshtë',
	'8219': 'Thonjëz-9 lartë e vetme e kthyer në të kundërtën',
	bdquo: 'Thonjëza-9 poshtë',
	hellip: 'Tri pika horizontale',
	trade: 'Shenja e Simbolit Tregtarë',
	'9658': 'Shenjë tregues kthyer djathtas-prapa',
	bull: 'Pulla',
	rarr: 'Shigjeta djathtas',
	rArr: 'Shenja të dyfishta djathtas',
	hArr: 'Shigjeta e dyfishë majtas-djathtas',
	diams: 'Karo me ngjyrë të zezë',
	asymp: 'Gati e barabar me'
} );
